# Generated by Django 5.2.7 on 2025-11-13 19:24

import django.utils.timezone
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("notices", "0003_alter_outage_start"),
    ]

    operations = [
        migrations.AddField(
            model_name="outage",
            name="reported_at",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
    ]
