# Generated by Django 5.2.7 on 2025-11-13 18:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("notices", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="maintenance",
            name="impact",
            field=models.TextField(blank=True),
        ),
        migrations.AddField(
            model_name="outage",
            name="impact",
            field=models.TextField(blank=True),
        ),
    ]
